<?php

/**
 * @file
 * Contains the AlexaCachedCertificate class.
 */

use Alexa\Request\Certificate;

/**
 * Extends \Alexa\Request\Certificate to add caching.
 *
 * Extends the default Amazon Alexa App library Certificate class to allow
 * Drupal-based caching of the downloaded Amazon certificate.
 */
class AlexaCachedCertificate extends Certificate {

  /**
   * {@inheritdoc}
   */
  public function getCertificate() {
    $cid = 'alexa:certificate:' . $this->certificateUrl;

    if ($cache = cache_get($cid)) {
      $certificate = $cache->data;
    }
    else {
      $certificate = $this->fetchCertificate();
      cache_set($cid, $certificate);
    }
    return $certificate;
  }

  /**
   * {@inheritdoc}
   */
  public function validateRequest($requestData) {
    if (!variable_get('alexa_dev_mode', FALSE)) {
      parent::validateRequest($requestData);
    }
  }

}
